==> nextalarm_0.2.4-1.tar.gz: nextalarm-0.2.4/src/nextalarm_ru.ts <==
﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="65"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished">будильники (на %1 ч)</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="161"/>
        <source>d</source>
        <translation type="unfinished">д</translation>
    </message>	
    <message>
        <location filename="alarmwindow.cpp" line="219"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>	
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished">Настройки Next Alarm</translation>
    </message>
	<message>
        <location filename="settingsdialog.ui" line="38"/>
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>	
	<message>
        <location filename="settingsdialog.ui" line="68"/>
        <source>B</source>
        <translation type="unfinished">Ж</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="86"/>
        <source>I</source>
        <translation type="unfinished">К</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="103"/>
        <source>Color</source>
        <translation type="unfinished">цвет</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="110"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="132"/>
        <source>Show</source>
        <translation type="unfinished">Показать</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="149"/>
        <source>Alarms only</source>
        <translation type="unfinished">Будильники</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Alarms + Calendar</source>
        <translation type="unfinished">Будильники + Календарь</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="159"/>
        <source>All Events</source>
        <translation type="unfinished">Все события</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="167"/>
        <source>Lines</source>
        <translation type="unfinished">Строк</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="193"/>
        <source>Width</source>
        <translation type="unfinished">Ширина</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="222"/>
        <source>recurrent</source>
        <translation type="unfinished">повторяющиеся</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="229"/>
        <source>Frame (h)</source>
        <translation type="unfinished">Диапазон (ч)</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="251"/>
        <source>Time Remain</source>
        <translation type="unfinished">Оставшееся время</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="270"/>
        <source>Header</source>
        <translation type="unfinished">Заголовок</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="282"/>
        <source>Title</source>
        <translation type="unfinished">Название</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="294"/>
        <source>Show empty</source>
        <translation type="unfinished">Показывать пустой</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="307"/>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="314"/>
        <source>About Qt</source>
        <translation type="unfinished">Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="118"/>
        <source>Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="119"/>
        <source>Developed with</source>
        <translation type="unfinished">Написано на</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="120"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation type="unfinished">Виджет, отображающий приближающиеся будильники</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="121"/>
        <source>Send reports to:</source>
        <translation type="unfinished">Написать автору</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="128"/>
        <source>About Next Alarm</source>
        <translation type="unfinished">О программе Next Alarm</translation>
    </message>
</context>
</TS>

==> nextalarm_0.2.7.tar.gz: nextalarm-0.2.7/src/nextalarm_ru.ts <==
﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="65"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished">будильники (на %1 ч)</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="162"/>
        <source>d</source>
        <translation type="unfinished">д</translation>
    </message>	
    <message>
        <location filename="alarmwindow.cpp" line="220"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>	
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished">Настройки Next Alarm</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="35"/>
        <source>Visual</source>
        <translation type="unfinished">Отображение</translation>
    </message>	
	<message>
        <location filename="settingsdialog.ui" line="49"/>
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>	
	<message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>B</source>
        <translation type="unfinished">Ж</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="97"/>
        <source>I</source>
        <translation type="unfinished">К</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="114"/>
        <source>Color</source>
        <translation type="unfinished">цвет</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="121"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="140"/>
        <source>Lines</source>
        <translation type="unfinished">Строк</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="166"/>
        <source>Width</source>
        <translation type="unfinished">Ширина</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="193"/>
        <source>Transparency</source>
        <translation type="unfinished">Прозрачность</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="216"/>
        <source>Alarms</source>
        <translation type="unfinished">Будильники</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="227"/>
        <source>Show</source>
        <translation type="unfinished">Показать</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="244"/>
        <source>Alarms only</source>
        <translation type="unfinished">Будильники</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="249"/>
        <source>Alarms + Calendar</source>
        <translation type="unfinished">Будильники + Календарь</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="254"/>
        <source>All Events</source>
        <translation type="unfinished">Все события</translation>
    </message>		
    <message>
        <location filename="settingsdialog.ui" line="268"/>
        <source>recurrent</source>
        <translation type="unfinished">повторяющиеся</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="275"/>
        <source>Frame (h)</source>
        <translation type="unfinished">Диапазон (ч)</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="297"/>
        <source>Time Remain</source>
        <translation type="unfinished">Оставшееся время</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="313"/>
        <source>Show widget Header</source>
        <translation type="unfinished">Заголовок Виджета</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="325"/>
        <source>Show alarm Title</source>
        <translation type="unfinished">Название Будильника</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="337"/>
        <source>Show when empty</source>
        <translation type="unfinished">Показывать пустой виджет</translation>
    </message>	
    <message>
        <location filename="settingsdialog.ui" line="352"/>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="359"/>
        <source>About Qt</source>
        <translation type="unfinished">Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="122"/>
        <source>Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="123"/>
        <source>Developed with</source>
        <translation type="unfinished">Написано на</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="124"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation type="unfinished">Виджет, отображающий приближающиеся будильники</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="125"/>
        <source>Send reports to:</source>
        <translation type="unfinished">Написать автору</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="132"/>
        <source>About Next Alarm</source>
        <translation type="unfinished">О программе Next Alarm</translation>
    </message>
</context>
</TS>
